@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: pvmdmimd.c,v 1.10 1997/10/01 15:36:06 pvmsrc Exp $";
+	"$Id: pvmdmimd.c,v 1.13 2001/09/25 21:19:28 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -39,19 +39,19 @@ static char rcsid[] =
  *			Initialization. Create a table to keep track of active nodes.
  *			argc, argv: passed from main.
  *
- *		int mpp_load(int flags, char *name, char *argv, int count, int tids[],
- *					int ptid):
+ *		int mpp_load( struct waitc_spawn *wxp ) 
+ *
  *			Load executable onto nodes; create new entries in task table,
  *			encode node number and process type into task IDs, etc.
  *
  *				Construction of Task ID:
  *
- *				 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1
- *				+-+-+---------------------+-+-----------+---------------------+
- *				|s|g|		host index	  |n| instance  |	node # (2048)	  |
- *				+-+-+---------------------+-+-----------+---------------------+
+ *			 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
+ *			+-+-+-----------------------+-+-----+--------------------------+
+ *			|s|g|		host index	    |n| prt |    	node # (16384)	   |
+ *			+-+-+-----------------------+-+-----+--------------------------+
  *
- *				The "n" bit is set for node task but clear for host task.
+ *			The "n" bit is set for node task but clear for host task.
  *
  *			flags:	exec options;
  *			name:	executable to be loaded;
@@ -89,13 +89,30 @@ static char rcsid[] =
  *			Remove node/process-type from active list.
  *			tp: task pointer.
  *
-$Log: pvmdmimd.c,v $
-Revision 1.10  1997/10/01 15:36:06  pvmsrc
-Removed unnecessary #include "fromlib.h" header.
-	- all consts now included in pvm3.h...
-	- header file eliminated.
-(Spanker=kohl)
-
+ * $Log: pvmdmimd.c,v $
+ * Revision 1.13  2001/09/25 21:19:28  pvmsrc
+ * Minor TMPNAMFUN()/tmpnam() cleanup.
+ * 	- moved macro def to pvm3.h, renamed PVMTNPMAN().
+ * 	- same for LEN_OF_TMP_NAM -> PVMTMPNAMLEN.
+ * 	- mostly a huge waste of time, since *both* tmpnam() & mktemp()
+ * 		produce the same "dangerous" warning message in Linux/gcc...
+ * 	- damn.
+ * (Spanker=kohl)
+ *
+ * Revision 1.12  2000/02/17 21:10:44  pvmsrc
+ * Cleaned up comments...  mpp_load() args...
+ * (Spanker=kohl)
+ *
+ * Revision 1.11  1999/07/08 19:00:28  kohl
+ * Fixed "Log" keyword placement.
+ * 	- indent with " * " for new CVS.
+ *
+ * Revision 1.10  1997/10/01  15:36:06  pvmsrc
+ * Removed unnecessary #include "fromlib.h" header.
+ * 	- all consts now included in pvm3.h...
+ * 	- header file eliminated.
+ * (Spanker=kohl)
+ *
  * Revision 1.9  1997/08/27  20:18:58  pvmsrc
  * Added blank args (0,0,0) in mpp_load() to make it call forkexec correctly.
  * Protocol needs to be changed to allow taskers to access IBM poe directly.
@@ -213,7 +230,7 @@ static int myndf = 0;
 static struct nodeset *busynodes;	/* active nodes; ordered by proc type */
 static char pvmtxt[512];		/* scratch for error log */
 static int ptypemask;			/* mask; we use these bits of ptype in tids */
-static char nodefile[L_tmpnam];	/* tmp node file */
+static char nodefile[PVMTMPNAMLEN];	/* tmp node file */
 static char **nodelist = 0;		/* default poe node list */
 static int partsize = 0;		/* number of nodes allocated */
 static int hostfileused = TRUE;         /* Check if MP_HOSTFILE used */
@@ -328,7 +345,7 @@ sp2hostfile(first, count)
 		pvmlogperror(pvmtxt);
 		return (char *)0;
 	}
-	(void)tmpnam(nodefile);
+	(void)PVMTMPNAMFUN(nodefile);
 	if (!(tmpfp = fopen(nodefile, "w"))) {
 		sprintf(pvmtxt, "sp2hostfile() fopen %s", nodefile);
 		pvmlogperror(pvmtxt);
