@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: lpvmshmem.c,v 1.41 1999/03/15 19:06:03 pvmsrc Exp $";
+	"$Id: lpvmshmem.c,v 1.45 2001/09/25 21:21:00 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -35,12 +35,30 @@ static char rcsid[] =
  *
  *	Libpvm core for MPP environment.
  *
-$Log: lpvmshmem.c,v $
-Revision 1.41  1999/03/15 19:06:03  pvmsrc
-Replaced sleep() calls with pvmsleep().
-	- Unix / Win32, C / Fortran compat...
-(Spanker=kohl)
-
+ * $Log: lpvmshmem.c,v $
+ * Revision 1.45  2001/09/25 21:21:00  pvmsrc
+ * Yanked "char *pvmgettmp();" decl - now in pvm3.h...
+ * (Spanker=kohl)
+ *
+ * Revision 1.44  2001/05/11 17:32:29  pvmsrc
+ * Eliminated references to sys_errlist & sys_nerr.
+ * 	- unnecessary, and we're whacking that crap anyway.
+ * (Spanker=kohl)
+ *
+ * Revision 1.43  2000/02/10 20:44:41  pvmsrc
+ * Replaced hard-coded /tmp for PVMSHMFILE.
+ * 	- use pvmgettmp() routine now to determine PVM temp dir.
+ * (Spanker=kohl)
+ *
+ * Revision 1.42  1999/07/08 19:00:02  kohl
+ * Fixed "Log" keyword placement.
+ * 	- indent with " * " for new CVS.
+ *
+ * Revision 1.41  1999/03/15  19:06:03  pvmsrc
+ * Replaced sleep() calls with pvmsleep().
+ * 	- Unix / Win32, C / Fortran compat...
+ * (Spanker=kohl)
+ *
  * Revision 1.40  1999/02/20  14:17:57  pvmsrc
  * Another try at the SGI compiler warning...  :-]
  * (Spanker=kohl)
@@ -474,6 +492,7 @@ Replaced sleep() calls with pvmsleep().
 #endif
 
 char *getenv();
+
 void hex_inadport __ProtoGlarp__ (( char *, struct sockaddr_in * ));
 
 /* These prototypes stop compiler casting structs to ints... */
@@ -499,8 +518,6 @@ int current_node();
 
 #ifndef HASERRORVARS
 extern int errno;					/* from libc */
-extern char *sys_errlist[];
-extern int sys_nerr;
 #endif
 
 /* XXX this should be in a header file not copied */
@@ -1459,6 +1476,7 @@ pvmbeatask()
 #endif
 	int key, firstkeytried;
 	int mytid;
+	char *pvmtmp;
 	TEV_DECLS
 
 	if (pvmmytid != -1)
@@ -1487,11 +1505,13 @@ pvmbeatask()
 #ifdef IMA_CSPP
 	int scid = get_scid();
 
+	pvmtmp = pvmgettmp();
+
 	if (scid > 1)
-		sprintf(fname, "/tmp/pvmt.%d.%d", pvm_useruid, scid);
+		sprintf(fname, "%s/pvmt.%d.%d", pvmtmp, pvm_useruid, scid);
 	else
 #endif
-		sprintf(fname, "/tmp/pvmt.%d", pvm_useruid);
+		sprintf(fname, "%s/pvmt.%d", pvmtmp, pvm_useruid);
 		if ((logfp = fopen(fname, "a")) == NULL)
 			pvmlogerror("pvmbeatask() can't open log file\n");
 #endif
@@ -2309,6 +2329,7 @@ dynbuf(tid, len)
 	int fd;
 	char fname[32];
 	struct shmpghdr *ph;
+	char *pvmtmp;
 
 	while (!(pp = peer_conn(tid, (int *)0)))
 		;
@@ -2319,7 +2340,8 @@ dynbuf(tid, len)
 	}
 
 	if (!(ph = (struct shmpghdr *)pp->p_dbuf)) {
-		sprintf(fname, PVMSHMFILE, tid);
+		pvmtmp = pvmgettmp();
+		sprintf(fname, PVMSHMFILE, pvmtmp, tid);
 		if ((fd = open(fname, O_CREAT|O_RDWR, 0600)) == -1 ||
 		(pp->p_dbuf = (char *)mmap(0, max(len,SHMBUFSIZE), PROT_READ|PROT_WRITE,
 #if defined(IMA_SGIMP) || defined(IMA_SGIMP6) || defined(IMA_SGIMP64)
