@@ -1,6 +1,6 @@
 
 static char rcsid[] =
-	"$Id: msgbox.c,v 1.19 1999/01/13 00:03:45 pvmsrc Exp $";
+	"$Id: msgbox.c,v 1.25 2001/02/07 23:15:49 pvmsrc Exp $";
 
 /*
  *         PVM version 3.4:  Parallel Virtual Machine System
@@ -35,17 +35,50 @@ static char rcsid[] =
  *
  *	Message mailbox database.
  *
-$Log: msgbox.c,v $
-Revision 1.19  1999/01/13 00:03:45  pvmsrc
-Fixed up mbox insert stuff, bugs & 3.3 compat (insert/lookup/delete).
-	- changed to always pass in -1 for index (internal arg only).
-	- handle minst correctly, supercedes overwritable else no way to
-		build a minst list from within a single task, always just look
-		for next unused index if minst set.
-	- check for pvm_insert() compat, if mbox exists and req != -1 (any),
-		then return PvmDenied (no overwrite in 3.3).
-(Spanker=kohl)
-
+ * $Log: msgbox.c,v $
+ * Revision 1.25  2001/02/07 23:15:49  pvmsrc
+ * 2nd Half of CYGWIN Check-ins...
+ * (Spanker=kohl)
+ *
+ * Revision 1.24  2000/02/16 21:59:47  pvmsrc
+ * Fixed up #include <sys/types.h> stuff...
+ * 	- use <bsd/sys/types.h> for IMA_TITN...
+ * 	- #include before any NEEDMENDIAN #includes...
+ * (Spanker=kohl)
+ *
+ * Revision 1.23  1999/12/13 18:13:41  pvmsrc
+ * Moved pvmmatchstring() routine to pvmcruft.c (for usage by pvmtester).
+ * Re-integrated two versions of mb_name() into one with #ifdefs for
+ * 	the USE_GNU_REGEX stuff.
+ * (Spanker=kohl)
+ *
+ * Revision 1.22  1999/12/10 21:30:45  pvmsrc
+ * Yanked GNU Regex Stuff.
+ * 	- re-activate using -DUSE_GNU_REGEX define...  if you must.
+ * 	- replaced full regular expression matching in mb_names()
+ * 		with good ole Unix style '*' globbing,
+ * 		via pvmmatchstring() a la Jeembo.
+ * (Spanker=kohl)
+ *
+ * Revision 1.21  1999/11/08 17:21:16  pvmsrc
+ * Added new PvmMboxDirectIndex() flag handling to mb_insert().
+ * 	- allow atomic re-insert at a specific index.
+ * (Spanker=kohl)
+ *
+ * Revision 1.20  1999/07/08 19:00:04  kohl
+ * Fixed "Log" keyword placement.
+ * 	- indent with " * " for new CVS.
+ *
+ * Revision 1.19  1999/01/13  00:03:45  pvmsrc
+ * Fixed up mbox insert stuff, bugs & 3.3 compat (insert/lookup/delete).
+ * 	- changed to always pass in -1 for index (internal arg only).
+ * 	- handle minst correctly, supercedes overwritable else no way to
+ * 		build a minst list from within a single task, always just look
+ * 		for next unused index if minst set.
+ * 	- check for pvm_insert() compat, if mbox exists and req != -1 (any),
+ * 		then return PvmDenied (no overwrite in 3.3).
+ * (Spanker=kohl)
+ *
  * Revision 1.18  1998/11/20  20:04:10  pvmsrc
  * Changes so that win32 will compile & build. Also, common
  * Changes so that compiles & builds on NT. Also
@@ -144,6 +177,7 @@ Fixed up mbox insert stuff, bugs & 3.3 compat (insert/lookup/delete).
 
 #include <stdio.h>
 #ifdef NEEDMENDIAN
+#include <sys/types.h>
 #include <machine/endian.h>
 #endif
 #ifdef NEEDENDIAN
@@ -154,12 +188,10 @@ Fixed up mbox insert stuff, bugs & 3.3 compat (insert/lookup/delete).
 #endif
 
 #include <pvm3.h>
-#ifdef WIN32
-#ifndef _XDR_HEADERS
-#define _XDR_HEADERS
+
+#if defined(WIN32) || defined(CYGWIN)
 #include "..\xdr\types.h"
 #include "..\xdr\xdr.h"
-#endif
 #else
 #include <rpc/types.h>
 #include <rpc/xdr.h>
@@ -177,9 +209,14 @@ Fixed up mbox insert stuff, bugs & 3.3 compat (insert/lookup/delete).
 #include "msgbox.h"
 #include "global.h"
 
+
+#ifdef USE_GNU_REGEX
 void *pvmcompileregex __ProtoGlarp__ (( char * ));
 int pvmmatchregex __ProtoGlarp__ (( void *, char * ));
 void pvmfreeregex __ProtoGlarp__ (( void ** ));
+#else
+int pvmmatchstring __ProtoGlarp__ (( char *, char * ));
+#endif
 
 
 /***************
@@ -286,7 +323,8 @@ mb_insert(tid, name, req, flags, mp)
 	struct pvmmentry *ep;
 	struct pvmmentry *ep2 = 0;
 
-	int cind;
+	int dind;	/* direct index	*/
+	int cind;	/* current index */
 
 	/* must change to always pass in -1 for 3.4 calls */
 	/* then can distinguish between 3.4 reinsert which succeeds
@@ -300,7 +338,11 @@ mb_insert(tid, name, req, flags, mp)
 		if (!(np = mc_new(name)))
 			return PvmNoMem;
 
-	cind = ( req == -1 ) ? 0 : req;
+	dind = PvmMboxDirectIndexOf( flags );
+
+	cind = ( req == -1 ) ?
+		( ( dind ) ? dind : 0 )
+		: req;
 
 	for (ep = np->mc_ent->me_link; ep != np->mc_ent; ep = ep->me_link)
 		if (ep->me_ind >= cind)
@@ -429,14 +471,18 @@ mb_names(tid, pattern, mp)
 	char *pattern;
 	struct pmsg *mp;
 {
-	void *pattbuff;
-
 	struct pvmmclass *np;
 	struct pvmmentry *ep;
 
+#ifdef USE_GNU_REGEX
+	void *pattbuff;
 	int pattglob = 0;
+#endif
+
 	int cnt;
 
+#ifdef USE_GNU_REGEX
+
 	/* Check for "*" Global Match Pattern */
 
 	if ( !strcmp( pattern, "*" ) )
@@ -447,6 +493,8 @@ mb_names(tid, pattern, mp)
 	if ( !pattglob )
 		pattbuff = pvmcompileregex( pattern );
 
+#endif
+
 	/* Count # of Classes */
 
 	cnt = 0;
@@ -454,10 +502,14 @@ mb_names(tid, pattern, mp)
 	for ( np = pvmmboxclasses->mc_link; np != pvmmboxclasses;
 			np = np->mc_link )
 	{
+#ifdef USE_GNU_REGEX
 		if ( pattglob
 				|| ( ( pattbuff ) ?
 					( pvmmatchregex( pattbuff, np->mc_name ) )
 					: ( !strcmp( pattern, np->mc_name ) ) ) )
+#else
+		if ( pvmmatchstring( np->mc_name, pattern ) )
+#endif
 		{
 			cnt++;
 		}
@@ -470,10 +522,14 @@ mb_names(tid, pattern, mp)
 	for ( np = pvmmboxclasses->mc_link; np != pvmmboxclasses;
 			np = np->mc_link )
 	{
+#ifdef USE_GNU_REGEX
 		if ( pattglob
 				|| ( ( pattbuff ) ?
 					( pvmmatchregex( pattbuff, np->mc_name ) )
 					: ( !strcmp( pattern, np->mc_name ) ) ) )
+#else
+		if ( pvmmatchstring( np->mc_name, pattern ) )
+#endif
 		{
 			pkstr( mp, np->mc_name );
 
@@ -499,8 +555,10 @@ mb_names(tid, pattern, mp)
 		}
 	}
 
+#ifdef USE_GNU_REGEX
 	if ( !pattglob && pattbuff )
 		pvmfreeregex( &pattbuff );
+#endif
 
 	return 0;
 }
